@@ -2,13 +2,14 @@
 //
 // KRotation screen saver for KDE
 // Copyright (C) 2004 Georg Drenkhahn
-// $Id: rotation.h 304354 2004-04-16 23:42:39Z kniederk $
+// $Id: rotation.h 465386 2005-09-29 15:44:07Z coolo $
 //
 //============================================================================
 
 #ifndef __ROTATION_H__
 #define __ROTATION_H__
 
+#include <math.h>
 // STL headers
 #include <valarray>
 // Qt headers
@@ -80,7 +81,7 @@ class EulerOdeSolver : public RkOdeSolver<double>
  * Class implements QGLWidget to display the KRotation screen saver. */
 class RotationGLWidget : public QGLWidget
 {
-   Q_OBJECT;
+   Q_OBJECT
 
   public:
    /** @brief Constructor of KRotation's GL widget
@@ -170,7 +171,7 @@ class RotationGLWidget : public QGLWidget
  * This class implements KScreenSaver for the KRotation screen saver. */
 class KRotationSaver : public KScreenSaver
 {
-   Q_OBJECT;
+   Q_OBJECT
 
   public:
    /** @brief Constructor of the KRotation screen saver object
@@ -297,7 +298,7 @@ class KRotationSaver : public KScreenSaver
  * This class handles the KRotation screen saver setup dialog. */
 class KRotationSetup : public KRotationSetupUi
 {
-   Q_OBJECT;
+   Q_OBJECT
 
   public:
    KRotationSetup(QWidget* parent = NULL, const char* name = NULL);
