@@ -417,8 +417,9 @@ void GlowClient::paintEvent( QPaintEvent * )
 	QColorGroup cg = widget()->colorGroup();
 	QColor titleColor = options()->color(ColorTitleBar, isActive());
 	QColor titleBlendColor = options()->color(ColorTitleBlend, isActive());
+	QColor bgColor = widget()->colorGroup().background();
 	QPainter p;
-	QPointArray pArray, pArray2, pArray3;
+	QPointArray pArray, pArray2, pArray3, pArray4;
 
 	// pixmap for title bar
 	QSize tBSize(width(), r_title.height());
@@ -443,7 +444,18 @@ void GlowClient::paintEvent( QPaintEvent * )
 		p.drawText(r_title.x(), 0,
 			r_title.width(), r_title.height(),
 			Qt::AlignLeft | Qt::AlignVCenter | Qt::SingleLine, caption());
-
+	
+		// draw split color beneath buttons top right
+		pArray4 = QPointArray(4);
+		pArray4.setPoint(0, tBSize.width()-1, tBSize.height()/2-1);
+		pArray4.setPoint(1, r_title.x()+r_title.width()-1+tBSize.height()/2,
+			tBSize.height()/2-1);
+		pArray4.setPoint(2, r_title.x()+r_title.width()-1, tBSize.height());
+		pArray4.setPoint(3, tBSize.width()-1, tBSize.height());
+		p.setPen(Qt::NoPen);
+		p.setBrush(bgColor);
+		p.drawPolygon(pArray4);
+				
 		// draw borders
 		pArray = QPointArray(3);
 		pArray.setPoint(0, tBSize.width()-1, tBSize.height()/2-1);
@@ -452,7 +464,7 @@ void GlowClient::paintEvent( QPaintEvent * )
 		pArray.setPoint(2, r_title.x()+r_title.width()-1, tBSize.height()-1);
 		p.setPen(titleCg.mid());
 		p.drawPolyline(pArray);
-		p.drawLine (0, tBSize.height()-1, tBSize.width()-1, tBSize.height()-1);
+		p.drawLine (0, tBSize.height()-1, r_title.x()+r_title.width()-1, tBSize.height()-1);
 
 		pArray2 = QPointArray(3);
 		pArray2.setPoint(0, 1, tBSize.height()-2);
@@ -518,6 +530,12 @@ void GlowClient::mouseDoubleClickEvent( QMouseEvent *e )
 		titlebarDblClickOperation();
 }
 
+void GlowClient::wheelEvent( QWheelEvent *e )
+{
+    if (isSetShade() || QRect( 0, 0, width(), titleHeight ).contains(e->pos()))
+        titlebarMouseWheelOperation( e->delta());
+}
+
 void GlowClient::activeChange()
 {
 	updateButtonPixmaps();
@@ -858,6 +876,9 @@ bool GlowClient::eventFilter( QObject* o, QEvent* e )
 	case QEvent::Show:
 	    showEvent( static_cast< QShowEvent* >( e ));
 	    return true;
+	case QEvent::Wheel:
+	    wheelEvent( static_cast< QWheelEvent* >( e ));
+	    return true;
 	default:
 	    break;
 	}
