@@ -1080,7 +1080,7 @@ void dotNETstyle::drawControl(ControlElement element,
 				             pixelMetric(PM_ButtonShiftVertical));
 			}
 
-			if (pb->text() && flags & Style_ButtonDefault) {
+			if (!pb->text().isEmpty() && (flags & Style_ButtonDefault)) {
 				p->setFont(QFont(p->font().family(), p->font().pointSize(), 75));
 			}
 
@@ -1114,12 +1114,12 @@ void dotNETstyle::drawControl(ControlElement element,
 				p->drawPixmap(pr.topLeft(), *pb->pixmap());
 			}
 
-			if (useTextShadows && pb->text() && enabled) {
+			if (useTextShadows && !pb->text().isEmpty() && enabled) {
 				p->setPen((flags & Style_Down ? cg.highlight().dark(135) : cg.background().dark(115)));
 				p->drawText(ur.x()+1, ur.y()+1, ur.width(), ur.height(), text_flags, pb->text());
 			}
 
-			if (pb->text()) {
+			if (!pb->text().isEmpty()) {
 				p->setPen(enabled ? cg.foreground() : pb->palette().disabled().buttonText());
 				p->drawText(ur, text_flags, pb->text());
 			}
