@@ -420,7 +420,7 @@ void PhaseStyle::drawPhaseTab(QPainter *painter,
       case QTabBar::RoundedAbove:
       case QTabBar::TriangularAbove: {
 	  // is there a corner widget?
-	  tabwidget = dynamic_cast<QTabWidget*>(bar->parent());
+	  tabwidget = ::qt_cast<QTabWidget*>(bar->parent());
 	  if (edge && tabwidget
 	      && tabwidget->cornerWidget(reverse_ ?
 					 Qt::TopRight : Qt::TopLeft)) {
@@ -499,7 +499,7 @@ void PhaseStyle::drawPhaseTab(QPainter *painter,
       case QTabBar::RoundedBelow:
       case QTabBar::TriangularBelow: {
 	  // is there a corner widget?
-	  tabwidget = dynamic_cast<QTabWidget*>(bar->parent());
+	  tabwidget = ::qt_cast<QTabWidget*>(bar->parent());
 	  if (edge && tabwidget
 	      && tabwidget->cornerWidget(reverse_ ?
 					 Qt::BottomRight : Qt::BottomLeft)) {
@@ -617,7 +617,7 @@ void PhaseStyle::drawPrimitive(PrimitiveElement element,
       case PE_HeaderSection: {
           // covers kicker taskbar buttons and menu titles
           QHeader* header = dynamic_cast<QHeader*>(painter->device());
-          widget = dynamic_cast<QWidget*>(painter->device());
+          widget =dynamic_cast<QWidget*>(painter->device());
 
           if (header) {
               horiz = (header->orientation() == Horizontal);
@@ -883,7 +883,7 @@ void PhaseStyle::drawPrimitive(PrimitiveElement element,
 
           if (widget && widget->parent() &&
               widget->parent()->inherits("QToolBar")) {
-              QToolBar *toolbar = dynamic_cast<QToolBar*>(widget->parent());
+              QToolBar *toolbar = ::qt_cast<QToolBar*>(widget->parent());
               if (toolbar) {
                   // toolbar not floating or in a QMainWindow
                   flat = flatToolbar(toolbar);
@@ -1079,7 +1079,7 @@ void PhaseStyle::drawKStylePrimitive(KStylePrimitive element,
           break;
 
       case KPE_SliderGroove: {
-          const QSlider* slider = dynamic_cast<const QSlider*>(widget);
+          const QSlider* slider = ::qt_cast<const QSlider*>(widget);
           if (slider) {
               if (slider->orientation() == Horizontal) {
                   y = cy - 3;
@@ -1095,7 +1095,7 @@ void PhaseStyle::drawKStylePrimitive(KStylePrimitive element,
       }
 
       case KPE_SliderHandle: {
-          const QSlider* slider = dynamic_cast<const QSlider*>(widget);
+          const QSlider* slider = ::qt_cast<const QSlider*>(widget);
           if (slider) {
               QColor color = (widget==hover_)
                   ? group.button().light(contrast)
@@ -1174,7 +1174,7 @@ void PhaseStyle::drawControl(ControlElement element,
       }
 
       case CE_PushButtonLabel: {
-          const QPushButton* button = dynamic_cast<const QPushButton*>(widget);
+          const QPushButton* button = ::qt_cast<const QPushButton*>(widget);
           if (!button) {
               KStyle::drawControl(element, painter, widget, rect, group,
                                   flags, option);
@@ -1251,7 +1251,7 @@ void PhaseStyle::drawControl(ControlElement element,
 
       case CE_CheckBoxLabel:
       case CE_RadioButtonLabel: {
-          const QButton *b = dynamic_cast<const QButton*>(widget);
+          const QButton *b = ::qt_cast<const QButton*>(widget);
           if (!b) return;
 
           int alignment = reverse_ ? AlignRight : AlignLeft;
@@ -1259,7 +1259,7 @@ void PhaseStyle::drawControl(ControlElement element,
                    group, flags & Style_Enabled, b->pixmap(), b->text());
 
           // only draw focus if content (forms on html won't)
-          if ((flags & Style_HasFocus) && ((b->text()) || b->pixmap())) {
+          if ((flags & Style_HasFocus) && ((!b->text().isNull()) || b->pixmap())) {
               drawPrimitive(PE_FocusRect, painter,
                             visualRect(subRect(SR_RadioButtonFocusRect,
                                                widget), widget),
@@ -1269,7 +1269,7 @@ void PhaseStyle::drawControl(ControlElement element,
       }
 
       case CE_DockWindowEmptyArea:  {
-          const QToolBar *tb = dynamic_cast<const QToolBar*>(widget);
+          const QToolBar *tb = ::qt_cast<const QToolBar*>(widget);
           if (tb) {
               // toolbar not floating or in a QMainWindow
               if (flatToolbar(tb)) {
@@ -1289,7 +1289,7 @@ void PhaseStyle::drawControl(ControlElement element,
           break;
 
       case CE_MenuBarItem: {
-          const QMenuBar *mbar = dynamic_cast<const QMenuBar*>(widget);
+          const QMenuBar *mbar = ::qt_cast<const QMenuBar*>(widget);
           if (!mbar) {
               KStyle::drawControl(element, painter, widget, rect, group,
                                   flags, option);
@@ -1320,7 +1320,7 @@ void PhaseStyle::drawControl(ControlElement element,
       }
 
       case CE_PopupMenuItem: {
-          const QPopupMenu *popup = dynamic_cast<const QPopupMenu*>(widget);
+          const QPopupMenu *popup = ::qt_cast<const QPopupMenu*>(widget);
           if (!popup) {
               KStyle::drawControl(element, painter, widget, rect, group,
                                   flags, option);
@@ -1481,7 +1481,7 @@ void PhaseStyle::drawControl(ControlElement element,
       }
 
       case CE_TabBarTab: {
-          const QTabBar* tab = dynamic_cast<const QTabBar*>(widget);
+          const QTabBar* tab = ::qt_cast<const QTabBar*>(widget);
           if (tab) {
               if ((widget == hover_) && (option.tab() == hovertab_)) {
                   flags |= Style_MouseOver;
@@ -1504,7 +1504,7 @@ void PhaseStyle::drawControl(ControlElement element,
       }
 
       case CE_ProgressBarContents: {
-          const QProgressBar* pbar = dynamic_cast<const QProgressBar*>(widget);
+          const QProgressBar* pbar = ::qt_cast<const QProgressBar*>(widget);
           if (!pbar) {
               KStyle::drawControl(element, painter, widget, rect, group,
                                   flags, option);
@@ -1534,7 +1534,7 @@ void PhaseStyle::drawControl(ControlElement element,
 
 #if (QT_VERSION >= 0x030200)
       case CE_ToolBoxTab: {
-          const QToolBox *box = dynamic_cast<const QToolBox*>(widget);
+          const QToolBox *box = ::qt_cast<const QToolBox*>(widget);
           if (!box) {
               KStyle::drawControl(element, painter, widget, rect, group,
                                   flags, option);
@@ -1624,7 +1624,7 @@ void PhaseStyle::drawComplexControl(ComplexControl control,
 
     switch (control) {
       case CC_ComboBox: {
-          const QComboBox * combo = dynamic_cast<const QComboBox*>(widget);
+          const QComboBox * combo = ::qt_cast<const QComboBox*>(widget);
           if (!combo) {
               KStyle::drawComplexControl(control, painter, widget, rect, group,
                                          flags, controls, active, option);
@@ -1675,7 +1675,7 @@ void PhaseStyle::drawComplexControl(ComplexControl control,
 
       case CC_ScrollBar: {
           // always a three button scrollbar
-          const QScrollBar *sb = dynamic_cast<const QScrollBar*>(widget);
+          const QScrollBar *sb = ::qt_cast<const QScrollBar*>(widget);
           if (!sb) {
               KStyle::drawComplexControl(control, painter, widget, rect, group,
                                          flags, controls, active, option);
@@ -1772,7 +1772,7 @@ void PhaseStyle::drawComplexControl(ComplexControl control,
       }
 
       case CC_SpinWidget: {
-          const QSpinWidget *spin = dynamic_cast<const QSpinWidget*>(widget);
+          const QSpinWidget *spin = ::qt_cast<const QSpinWidget*>(widget);
           if (!spin) {
               KStyle::drawComplexControl(control, painter, widget, rect, group,
                                          flags, controls, active, option);
@@ -1832,7 +1832,7 @@ void PhaseStyle::drawComplexControl(ComplexControl control,
       }
 
       case CC_ToolButton: {
-          const QToolButton *btn = dynamic_cast<const QToolButton*>(widget);
+          const QToolButton *btn = ::qt_cast<const QToolButton*>(widget);
           if (!btn) {
               KStyle::drawComplexControl(control, painter, widget, rect, group,
                                          flags, controls, active, option);
@@ -1848,7 +1848,7 @@ void PhaseStyle::drawComplexControl(ComplexControl control,
 
           // check for QToolBar parent
           if (btn->parent() && btn->parent()->inherits("QToolBar")) {
-              toolbar = dynamic_cast<QToolBar*>(btn->parent());
+              toolbar = ::qt_cast<QToolBar*>(btn->parent());
               if (toolbar) {
                   horiz = (toolbar->orientation() == Qt::Horizontal);
                   if (normal) { // draw background
@@ -1874,8 +1874,8 @@ void PhaseStyle::drawComplexControl(ComplexControl control,
           else if (btn->parent() &&
                    btn->parent()->inherits(QTOOLBAREXTENSION)) {
               QWidget *extension;
-              if ((extension = dynamic_cast<QWidget*>(btn->parent()))) {
-                  toolbar = dynamic_cast<QToolBar*>(extension->parent());
+              if ((extension = ::qt_cast<QWidget*>(btn->parent()))) {
+                  toolbar = ::qt_cast<QToolBar*>(extension->parent());
                   if (toolbar) {
                       horiz = (toolbar->orientation() == Qt::Horizontal);
                       if (normal) { // draw background
@@ -1969,7 +1969,7 @@ int PhaseStyle::pixelMetric(PixelMetric metric, const QWidget *widget) const
           return 24;
 
       case PM_TabBarTabVSpace:
-          if (const QTabBar *tb = dynamic_cast<const QTabBar*>(widget)) {
+          if (const QTabBar *tb = ::qt_cast<const QTabBar*>(widget)) {
               if (tb->shape() == QTabBar::RoundedAbove) {
                   return 10;
               } else {
@@ -2066,7 +2066,7 @@ QRect PhaseStyle::querySubControlMetrics(ComplexControl control,
       }
 
       case CC_ScrollBar: {
-          const QScrollBar *sb = dynamic_cast<const QScrollBar*>(widget);
+          const QScrollBar *sb = ::qt_cast<const QScrollBar*>(widget);
           if (!sb) break;
 
           bool horizontal = (sb->orientation() == Qt::Horizontal);
@@ -2135,7 +2135,7 @@ QSize PhaseStyle::sizeFromContents(ContentsType contents,
 
     switch (contents) {
       case CT_PushButton: {
-          const QPushButton* button = dynamic_cast<const QPushButton*>(widget);
+          const QPushButton* button = ::qt_cast<const QPushButton*>(widget);
           if (!button) {
               return KStyle::sizeFromContents(contents, widget, contentsize,
                                               option);
@@ -2156,7 +2156,7 @@ QSize PhaseStyle::sizeFromContents(ContentsType contents,
 
       case CT_PopupMenuItem: {
           if (!widget || option.isDefault()) return contentsize;
-          const QPopupMenu *popup = dynamic_cast<const QPopupMenu*>(widget);
+          const QPopupMenu *popup = ::qt_cast<const QPopupMenu*>(widget);
           if (!popup) {
               return KStyle::sizeFromContents(contents, widget, contentsize,
                                               option);
@@ -2250,21 +2250,21 @@ bool PhaseStyle::eventFilter(QObject *object, QEvent *event)
         // KDE Toolbar Widget
         // patch by Daniel Brownlees <dbrownlees@paradise.net.nz>
         if (object->parent() && !qstrcmp(object->name(), KTOOLBARWIDGET)) {
-            if (0 == (widget = dynamic_cast<QWidget*>(object))) return false;
-            QWidget *parent = dynamic_cast<QWidget*>(object->parent());
+            if (0 == (widget = ::qt_cast<QWidget*>(object))) return false;
+            QWidget *parent = ::qt_cast<QWidget*>(object->parent());
             int px = widget->x(), py = widget->y();
             // find the toolbar
             while (parent && parent->parent()
-                   && !dynamic_cast<QToolBar*>(parent)) {
+                   && !::qt_cast<QToolBar*>(parent)) {
                 px += parent->x();
                 py += parent->y();
-                parent = dynamic_cast<QWidget*>(parent->parent());
+                parent = ::qt_cast<QWidget*>(parent->parent());
             }
             if (!parent) return false;
             widget->rect().rect(&x, &y, &w, &h);
             QRect prect = parent->rect();
 
-            toolbar = dynamic_cast<QToolBar*>(parent);
+            toolbar = ::qt_cast<QToolBar*>(parent);
             horiz = (toolbar) ? (toolbar->orientation() == Qt::Horizontal)
                 : (prect.height() < prect.width());
             QPainter painter(widget);
@@ -2287,9 +2287,9 @@ bool PhaseStyle::eventFilter(QObject *object, QEvent *event)
         }
 
         // QToolBarExtensionWidget
-        else if ((object->parent()) &&
-                 (toolbar = dynamic_cast<QToolBar*>(object->parent()))) {
-            if (0 == (widget = dynamic_cast<QWidget*>(object))) return false;
+        else if (object && object->isWidgetType() && object->parent() &&
+                 (toolbar = ::qt_cast<QToolBar*>(object->parent()))) {
+            if (0 == (widget = ::qt_cast<QWidget*>(object))) return false;
             horiz = (toolbar->orientation() == Qt::Horizontal);
             QPainter painter(widget);
             widget->rect().rect(&x, &y, &w, &h);
@@ -2319,7 +2319,7 @@ bool PhaseStyle::eventFilter(QObject *object, QEvent *event)
         }
 
         // QFrame lines (do this guy last)
-        else if (0 != (frame = dynamic_cast<QFrame*>(object))) {
+        else if (0 != (frame = ::qt_cast<QFrame*>(object))) {
             QFrame::Shape shape = frame->frameShape();
             switch (shape) {
               case QFrame::HLine:
@@ -2349,34 +2349,34 @@ bool PhaseStyle::eventFilter(QObject *object, QEvent *event)
             ::qt_cast<QSlider*>(object) ||
             object->inherits(QSPLITTERHANDLE)) {
             if (event->type() == QEvent::Enter) {
-                if (0 != (widget = dynamic_cast<QWidget*>(object)) &&
+                if (0 != (widget = ::qt_cast<QWidget*>(object)) &&
                     widget->isEnabled()) {
                     hover_ = widget;
                     widget->repaint(false);
                 }
             } else if (event->type() == QEvent::Leave) {
-                if (0 != (widget = dynamic_cast<QWidget*>(object))) {
+                if (0 != (widget = ::qt_cast<QWidget*>(object))) {
                     hover_ = 0;
                     widget->repaint(false);
                 }
             }
         } else if (::qt_cast<QTabBar*>(object)) { // special case for qtabbar
             if (event->type() == QEvent::Enter) {
-                if (0 != (widget = dynamic_cast<QWidget*>(object)) &&
+                if (0 != (widget = ::qt_cast<QWidget*>(object)) &&
                     widget->isEnabled()) {
                     hover_ = widget;
                     hovertab_ = 0;;
                     widget->repaint(false);
                 }
             } else if (event->type() == QEvent::Leave) {
-                if (0 != (widget = dynamic_cast<QWidget*>(object))) {
+                if (0 != (widget = ::qt_cast<QWidget*>(object))) {
                     hover_ = 0;
                     hovertab_ = 0;;
                     widget->repaint(false);
                 }
             } else if (event->type() == QEvent::MouseMove) {
                 QTabBar *tabbar;
-                if (0 != (tabbar = dynamic_cast<QTabBar*>(object))) {
+                if (0 != (tabbar = ::qt_cast<QTabBar*>(object))) {
                     QMouseEvent *me;
                     if (0 != (me = dynamic_cast<QMouseEvent*>(event))) {
                         QTab *tab = tabbar->selectTab(me->pos());
